CIA (``taurex.cia``)
====================

Base Class
---------------------

.. automodule:: taurex.cia.cia
   :members:
   :undoc-members:
   :show-inheritance:

HITRAN CIA (``.cia``)
---------------------------

.. automodule:: taurex.cia.hitrancia
   :members:
   :undoc-members:
   :show-inheritance:


Pickle CIA (``.db``)
---------------------------

.. automodule:: taurex.cia.picklecia
   :members:
   :undoc-members:
   :show-inheritance:

